@@ -1,13 +1,13 @@
 """Mockup of potential integration with 3rd-party task managment suite"""
 
 
-import pyblish.backend.plugin
+import pyblish
 from pyblish.vendor import mock
 
 api = mock.MagicMock()
 
 
-class ConformInstancesFail(pyblish.backend.plugin.Conformer):
+class ConformInstancesFail(pyblish.Conformer):
     hosts = ['python']
     families = ['test.family']
     version = (0, 1, 0)
