@@ -1,11 +1,10 @@
 """This plugin is incomplete and can't be used"""
 
-import pyblish.backend.lib
-import pyblish.backend.plugin
+import pyblish
 
 
-@pyblish.backend.lib.log
-class SelectMissingHosts(pyblish.backend.plugin.Selector):
+@pyblish.log
+class SelectMissingHosts(pyblish.Selector):
     """Select instances"""
 
     version = (0, 1, 0)
