@@ -2,10 +2,9 @@ import os
 import sys
 import shutil
 
-import pyblish.main
+import pyblish
 import pyblish.backend.lib
 import pyblish.backend.config
-import pyblish.backend.plugin
 
 from pyblish.vendor import yaml
 
@@ -22,7 +21,7 @@ def test_modifying_config_at_run_time():
     """Altering config at run-time works"""
     path = '/invalid/path'
     pyblish.backend.config.paths.append(path)
-    assert path in pyblish.backend.plugin.plugin_paths()
+    assert path in pyblish.plugin_paths()
     pyblish.backend.config.paths.remove(path)
 
 
@@ -92,7 +91,7 @@ def test_custom_paths():
         paths = getattr(pyblish.backend.config, 'paths', None)
         assert paths
 
-        plugins = pyblish.backend.plugin.discover('validators')
+        plugins = pyblish.discover('validators')
         plugin_names = [p.__name__ for p in plugins]
         assert 'ValidateCustomInstance' in plugin_names
 
